@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.33_01';
+our $VERSION = '0.02';
 
 use AnyEvent::Stomper::Frame;
 use AnyEvent::Stomper::Error;
@@ -14,10 +14,9 @@ use AnyEvent;
 use AnyEvent::Handle;
 use Scalar::Util qw( looks_like_number weaken );
 use List::Util qw( max );
-use List::MoreUtils qw( bsearch_index );
 use Carp qw( croak );
 
-my %ERROR_CODES;
+our %ERROR_CODES;
 
 BEGIN {
   %ERROR_CODES = %AnyEvent::Stomper::Error::ERROR_CODES;
@@ -27,9 +26,9 @@ BEGIN {
 
 use constant {
   # Default values
-  D_HOST      => 'localhost',
-  D_PORT      => 61613,
-  D_HEARTBEAT => [ 0, 0 ],
+  D_HOST       => 'localhost',
+  D_PORT       => 61613,
+  D_HEART_BEAT => [ 0, 0 ],
 
   %ERROR_CODES,
 
@@ -47,11 +46,6 @@ my %SUBUNSUB_CMDS = (
   UNSUBSCRIBE => 1,
 );
 
-my %ACK_CMDS = (
-  ACK  => 1,
-  NACK => 1,
-);
-
 my %NEED_RECEIPT = (
   CONNECT    => 1,
   DISCONNECT => 1,
@@ -66,9 +60,6 @@ my %ESCAPE_MAP = (
 );
 my %UNESCAPE_MAP = reverse %ESCAPE_MAP;
 
-my $RECEIPT_SEQ = 1;
-my $MESSAGE_SEQ = 1;
-
 
 sub new {
   my $class  = shift;
@@ -76,45 +67,32 @@ sub new {
 
   my $self = bless {}, $class;
 
-  $self->{host}            = $params{host} || D_HOST;
-  $self->{port}            = $params{port} || D_PORT;
-  $self->{login}           = $params{login};
-  $self->{passcode}        = $params{passcode};
-  $self->{vhost}           = $params{vhost};
-  $self->{lazy}            = $params{lazy};
-  $self->{handle_params}   = $params{handle_params} || {};
-  $self->{default_headers} = $params{default_headers} || {};
-  $self->{on_connect}      = $params{on_connect};
-  $self->{on_disconnect}   = $params{on_disconnect};
+  $self->{host} = $params{host} || D_HOST;
+  $self->{port} = $params{port} || D_PORT;
+  $self->{login}    = $params{login};
+  $self->{passcode} = $params{passcode};
+  $self->{vhost}    = $params{vhost};
 
-  if ( defined $params{heartbeat} ) {
-    unless ( ref( $params{heartbeat} ) eq 'ARRAY' ) {
-      croak q{"heartbeat" must be specified as array reference};
+  if ( defined $params{heart_beat} ) {
+    unless ( ref( $params{heart_beat} ) eq 'ARRAY' ) {
+      croak qq{"heart_beat" must be specified as array reference};
     }
-
-    foreach my $val ( @{ $params{heartbeat} } ) {
+    foreach my $val ( @{ $params{heart_beat} } ) {
       if ( $val =~ /\D/ ) {
-        croak q{"heartbeat" values must be an integer numbers};
+        croak qq{"heart_beat" values must be an integer numbers};
       }
     }
 
-    $self->{heartbeat} = $params{heartbeat};
+    $self->{heart_beat} = $params{heart_beat};
   }
   else {
-    $self->{heartbeat} = D_HEARTBEAT;
+    $self->{heart_beat} = D_HEART_BEAT;
   }
 
-  if ( defined $params{command_headers} ) {
-    unless ( ref( $params{command_headers} ) eq 'HASH' ) {
-      croak q{"command_headers" must be specified as hash reference};
-    }
-
-    my %command_headers;
-    while ( my ( $cmd_name, $headers ) = each %{ $params{command_headers} } ) {
-      $command_headers{ uc($cmd_name) } = $headers;
-    }
-    $self->{command_headers} = \%command_headers;
-  }
+  $self->{lazy}          = $params{lazy};
+  $self->{handle_params} = $params{handle_params} || {};
+  $self->{on_connect}    = $params{on_connect};
+  $self->{on_disconnect} = $params{on_disconnect};
 
   $self->connection_timeout( $params{connection_timeout} );
   $self->reconnect_interval( $params{reconnect_interval} );
@@ -122,9 +100,7 @@ sub new {
 
   $self->_reset_internals;
   $self->{_input_queue}      = [];
-  $self->{_temp_input_queue} = [];
-  $self->{_write_queue}      = [];
-  $self->{_temp_write_queue} = [];
+  $self->{_temp_queue}       = [];
   $self->{_pending_receipts} = {};
   $self->{_subs}             = {};
 
@@ -145,6 +121,14 @@ sub execute {
   return;
 }
 
+sub force_disconnect {
+  my $self = shift;
+
+  $self->_disconnect();
+
+  return;
+}
+
 # Generate methods
 {
   no strict qw( refs );
@@ -226,14 +210,6 @@ sub on_error {
   }
 }
 
-sub force_disconnect {
-  my $self = shift;
-
-  $self->_disconnect();
-
-  return;
-}
-
 sub _connect {
   my $self = shift;
 
@@ -247,7 +223,6 @@ sub _connect {
     on_rtimeout      => $self->_create_on_rtimeout,
     on_eof           => $self->_create_on_eof,
     on_error         => $self->_create_on_handle_error,
-    on_drain         => $self->_create_on_drain,
     on_read          => $self->_create_on_read,
   );
 
@@ -345,23 +320,6 @@ sub _create_on_handle_error {
   };
 }
 
-sub _create_on_drain {
-  my $self = shift;
-
-  weaken($self);
-
-  return sub {
-    return unless @{ $self->{_write_queue} };
-
-    $self->{_temp_write_queue} = $self->{_write_queue};
-    $self->{_write_queue} = [];
-
-    while ( my $cmd = shift @{ $self->{_temp_write_queue} } ) {
-      $cmd->{on_receipt}->();
-    }
-  };
-}
-
 sub _create_on_read {
   my $self = shift;
 
@@ -379,9 +337,9 @@ sub _create_on_read {
       return if $handle->destroyed;
 
       if ( defined $cmd_name ) {
-        my $content_length;
-        if ( defined $headers->{'content-length'} ) {
-          $content_length = $headers->{'content-length'};
+        my $content_length = $headers->{'content-length'};
+
+        if ( defined $content_length ) {
           return if length( $handle->{rbuf} ) < $content_length + 1;
         }
         else {
@@ -421,44 +379,29 @@ sub _prepare {
   my $cmd_name = uc(shift);
   my $args     = shift;
 
-  my %params;
-
-  if ( ref( $args->[-1] ) eq 'CODE'
-    && scalar @{$args} % 2 > 0 )
-  {
-    if ( $cmd_name eq 'SUBSCRIBE' ) {
-      $params{on_message} = pop @{$args};
-    }
-    else {
-      $params{on_receipt} = pop @{$args};
+  my $cbs;
+  if ( ref( $args->[-1] ) eq 'HASH' ) {
+    $cbs = pop @{$args};
+  }
+  else {
+    $cbs = {};
+    if ( ref( $args->[-1] ) eq 'CODE' ) {
+      if ( $cmd_name eq 'SUBSCRIBE' ) {
+        $cbs->{on_message} = pop @{$args};
+      }
+      else {
+        $cbs->{on_receipt} = pop @{$args};
+      }
     }
   }
-
-  my %headers = @{$args};
-
-  foreach my $name ( qw( body on_receipt on_message ) ) {
-    if ( defined $headers{$name} ) {
-      $params{$name} = delete $headers{$name};
-    }
-  }
-  if ( exists $ACK_CMDS{$cmd_name} ) {
-    $params{message} = delete $headers{message};
-  }
-
-  %headers = (
-    %{ $self->{default_headers} },
-
-    defined $self->{command_headers}{$cmd_name}
-    ? %{ $self->{command_headers}{$cmd_name} }
-    : (),
-
-    %headers,
-  );
+  my %cmd_headers = @{$args};
+  my $body        = delete $cmd_headers{body};
 
   my $cmd = {
     name    => $cmd_name,
-    headers => \%headers,
-    %params,
+    headers => \%cmd_headers,
+    body    => $body,
+    %{$cbs},
   };
 
   unless ( defined $cmd->{on_receipt} ) {
@@ -469,10 +412,10 @@ sub _prepare {
       my $err     = shift;
 
       if ( defined $err ) {
-        $self->{on_error}->($err);
+        $self->{on_error}->( $err, $receipt );
         return;
       }
-    };
+    }
   }
 
   return $cmd;
@@ -487,11 +430,6 @@ sub _execute {
   {
     croak '"on_message" callback must be specified';
   }
-  elsif ( exists $ACK_CMDS{ $cmd->{name} }
-    && !defined $cmd->{message} )
-  {
-    croak '"message" parameter must be specified';
-  }
 
   unless ( $self->{_ready} ) {
     if ( defined $self->{_handle} ) {
@@ -510,8 +448,6 @@ sub _execute {
         && $self->{reconnect_interval} > 0 )
       {
         unless ( defined $self->{_reconnect_timer} ) {
-          weaken($self);
-
           $self->{_reconnect_timer} = AE::timer(
             $self->{reconnect_interval}, 0,
             sub {
@@ -542,30 +478,11 @@ sub _push_write {
 
   my $cmd_headers = $cmd->{headers};
 
-  if ( exists $ACK_CMDS{ $cmd->{name} } ) {
-    unless ( $self->_check_ack( $cmd->{message} ) ) {
-      my $err = _new_error( "Unexpected $cmd->{name} sent.", E_OPRN_ERROR );
-      AE::postpone { $cmd->{on_receipt}->( undef, $err ) };
-
-      return;
-    }
-
-    my $msg_headers = $cmd->{message}->headers;
-
-    if ( $self->{_version} <= 1.1 ) {
-      $cmd_headers->{'message-id'} = $msg_headers->{'message-id'};
-      if ( $self->{_version} > 1.0 ) {
-        $cmd_headers->{subscription} = $msg_headers->{subscription};
-      }
-    }
-    else {
-      $cmd_headers->{id} = $msg_headers->{ack};
-    }
-  }
-
+  my $need_receipt;
   if ( exists $NEED_RECEIPT{ $cmd->{name} }
     || defined $cmd_headers->{receipt} )
   {
+    $need_receipt = 1;
     if ( $cmd->{name} eq 'CONNECT' ) {
       $self->{_pending_receipts}{CONNECTED} = $cmd;
     }
@@ -573,42 +490,39 @@ sub _push_write {
       if ( !defined $cmd_headers->{receipt}
         || $cmd_headers->{receipt} eq 'auto' )
       {
-        $cmd_headers->{receipt} = 'R_' . $self->{_session_id} . '.'
-            . $RECEIPT_SEQ++;
+        $cmd_headers->{receipt} = $self->{_session_id} . '@@'
+            . $self->{_receipt_seq}++;
       }
       $self->{_pending_receipts}{ $cmd_headers->{receipt} } = $cmd;
     }
   }
-  else {
-    push( @{ $self->{_write_queue} }, $cmd );
-  }
 
-  my $body = $cmd->{body};
-  unless ( defined $body ) {
-    $body = '';
+  unless ( defined $cmd->{body} ) {
+    $cmd->{body} = '';
   }
   unless ( defined $cmd_headers->{'content-length'} ) {
-    $cmd_headers->{'content-length'} = length($body);
+    $cmd_headers->{'content-length'} = length( $cmd->{body} );
   }
 
-  my $frame_str = $cmd->{name} . EOL;
+  my $frame_str = uc( $cmd->{name} ) . EOL;
   while ( my ( $name, $value ) = each %{$cmd_headers} ) {
-    unless ( defined $value ) {
-      $value = '';
-    }
     $frame_str .= _escape($name) . ':' . _escape($value) . EOL;
   }
-  $frame_str .= EOL . "$body\0";
+  $frame_str .= EOL . $cmd->{body} . "\0";
 
   $self->{_handle}->push_write($frame_str);
 
+  unless ($need_receipt) {
+    AE::postpone { $cmd->{on_receipt}->() };
+  }
+
   return;
 }
 
 sub _login {
   my $self = shift;
 
-  my ( $cx, $cy ) = @{ $self->{heartbeat} };
+  my ( $cx, $cy ) = @{ $self->{heart_beat} };
 
   if ( $cy > 0 ) {
     $self->_rtimeout($cy);
@@ -661,10 +575,8 @@ sub _login {
           }
         }
 
-        $self->{_ready} = 1;
-        $self->{_version}
-            = version->parse( $receipt_headers->{version} || 1.0 );
-        $self->{_session_id} = $receipt_headers->{session} || '';
+        $self->{_ready}      = 1;
+        $self->{_session_id} = $receipt_headers->{session};
 
         $self->_process_input_queue;
       },
@@ -697,47 +609,16 @@ sub _wtimeout {
 sub _process_input_queue {
   my $self = shift;
 
-  $self->{_temp_input_queue}  = $self->{_input_queue};
+  $self->{_temp_queue}  = $self->{_input_queue};
   $self->{_input_queue} = [];
 
-  while ( my $cmd = shift @{ $self->{_temp_input_queue} } ) {
+  while ( my $cmd = shift @{ $self->{_temp_queue} } ) {
     $self->_push_write($cmd);
   }
 
   return;
 }
 
-sub _check_ack {
-  my $self = shift;
-  my $msg  = shift;
-
-  my $msg_headers = $msg->headers;
-  my $sub_id  = $msg_headers->{subscription} || $msg_headers->{destination};
-  my $sub     = $self->{_subs}{$sub_id};
-  my $msg_tag = $msg_headers->{'message-tag'};
-
-  if ( defined $sub ) {
-    if ( defined $sub->{pending_acks} ) {
-      if ( ref( $sub->{pending_acks} ) eq 'ARRAY' ) {
-        my $i = bsearch_index {
-          $msg_tag > $_ ? -1 : $msg_tag < $_ ? 1 : 0;
-        }
-        @{ $sub->{pending_acks} };
-
-        if ( $i >= 0 ) {
-          splice( @{ $sub->{pending_acks} }, 0, $i + 1 );
-          return 1;
-        }
-      }
-      else {    # HASH
-        return 1 if delete $sub->{pending_acks}{$msg_tag};
-      }
-    }
-  }
-
-  return;
-}
-
 sub _process_frame {
   my $self  = shift;
   my $frame = shift;
@@ -768,9 +649,9 @@ sub _process_message {
 
   my $msg_headers = $msg->headers;
   my $sub_id = $msg_headers->{subscription} || $msg_headers->{destination};
-  my $sub    = $self->{_subs}{$sub_id};
+  my $cmd    = $self->{_subs}{$sub_id};
 
-  unless ( defined $sub ) {
+  unless ( defined $cmd ) {
     my $err = _new_error(
       qq{Don't know how process MESSAGE frame. Unknown subscription "$sub_id"},
       E_UNEXPECTED_DATA
@@ -780,19 +661,7 @@ sub _process_message {
     return;
   }
 
-  my $msg_tag = $MESSAGE_SEQ++;
-  $msg_headers->{'message-tag'} = $msg_tag;
-
-  if ( defined $sub->{pending_acks} ) {
-    if ( ref( $sub->{pending_acks} ) eq 'ARRAY' ) {
-      push( @{ $sub->{pending_acks} }, $msg_tag );
-    }
-    else {    # HASH
-      $sub->{pending_acks}{$msg_tag} = 1;
-    }
-  }
-
-  $sub->{on_message}->($msg);
+  $cmd->{on_message}->($msg);
 
   return;
 }
@@ -820,15 +689,6 @@ sub _process_receipt {
 
     if ( $cmd->{name} eq 'SUBSCRIBE' ) {
       $self->{_subs}{$sub_id} = $cmd;
-
-      if ( defined $cmd_headers->{ack} ) {
-        if ( $cmd_headers->{ack} eq 'client' ) {
-          $cmd->{pending_acks} = [];
-        }
-        elsif ( $cmd_headers->{ack} eq 'client-individual' ) {
-          $cmd->{pending_acks} = {};
-        }
-      }
     }
     else {    # UNSUBSCRIBE
       delete $self->{_subs}{$sub_id};
@@ -891,9 +751,9 @@ sub _reset_internals {
   $self->{_connected}       = 0;
   $self->{_login_state}     = S_NEED_DO;
   $self->{_ready}           = 0;
-  $self->{_version}         = undef;
   $self->{_session_id}      = undef;
   $self->{_reconnect_timer} = undef;
+  $self->{_receipt_seq}     = 1;
 
   return;
 }
@@ -906,9 +766,7 @@ sub _abort {
   my %subs            = %{ $self->{_subs} };
 
   $self->{_input_queue}      = [];
-  $self->{_temp_input_queue} = [];
-  $self->{_write_queue}      = [];
-  $self->{_temp_write_queue} = [];
+  $self->{_temp_queue}       = [];
   $self->{_pending_receipts} = {};
   $self->{_subs}             = {};
 
@@ -929,8 +787,8 @@ sub _abort {
         my $err = _new_error( qq{Subscription "$sub_id" lost: $err_msg},
             $err_code, $err_frame );
 
-        my $sub = $subs{$sub_id};
-        $sub->{on_receipt}->( undef, $err );
+        my $cmd = $subs{$sub_id};
+        $cmd->{on_receipt}->( undef, $err );
       }
     }
 
@@ -949,9 +807,7 @@ sub _queued_commands {
 
   return (
     values %{ $self->{_pending_receipts} },
-    @{ $self->{_temp_write_queue} },
-    @{ $self->{_write_queue} },
-    @{ $self->{_temp_input_queue} },
+    @{ $self->{_temp_queue} },
     @{ $self->{_input_queue} },
   );
 }
@@ -1024,30 +880,31 @@ AnyEvent::Stomper - Flexible non-blocking STOMP client
     id          => 'foo',
     destination => '/queue/foo',
 
-    on_receipt => sub {
-      my $err = $_[1];
+    { on_receipt => sub {
+        my $err = $_[1];
+
+        if ( defined $err ) {
+          warn $err->message . "\n";
+          $cv->send;
+
+          return;
+        }
+
+        $stomper->send(
+          destination => '/queue/foo',
+          body        => 'Hello, world!',
+        );
+      },
+
+      on_message => sub {
+        my $msg = shift;
+
+        my $body = $msg->body;
+        print "Consumed: $body\n";
 
-      if ( defined $err ) {
-        warn $err->message . "\n";
         $cv->send;
-
-        return;
-      }
-
-      $stomper->send(
-        destination => '/queue/foo',
-        body        => 'Hello, world!',
-      );
-    },
-
-    on_message => sub {
-      my $msg = shift;
-
-      my $body = $msg->body;
-      print "Consumed: $body\n";
-
-      $cv->send;
-    },
+      },
+    }
   );
 
   $cv->recv;
@@ -1070,7 +927,7 @@ L<https://stomp.github.io/index.html>
     login              => 'guest',
     passcode           => 'guest',
     vhost              => '/',
-    heartbeat          => [ 5000, 5000 ],
+    heart_beat         => [ 5000, 5000 ],
     connection_timeout => 5,
     lazy               => 1,
     reconnect_interval => 5,
@@ -1112,7 +969,7 @@ The password used to authenticate against a secured STOMP server.
 
 The name of a virtual host that the client wishes to connect to.
 
-=item heartbeat => \@heartbeat
+=item heart_beat => \@heart_beat
 
 Heart-beating can optionally be used to test the healthiness of the underlying
 TCP connection and to make sure that the remote end is alive and kicking. The
@@ -1121,7 +978,7 @@ STOMP server. C<0> means, that the client will not send heart-beats. The second
 number sets interval in milliseconds between incoming heart-beats from the
 STOMP server. C<0> means, that the client does not want to receive heart-beats.
 
-  heartbeat => [ 5000, 5000 ],
+  heart_beat => [ 5000, 5000 ],
 
 Not set by default.
 
@@ -1146,16 +1003,8 @@ Disabled by default.
 
 =item reconnect_interval => $reconnect_interval
 
-If the connection to the server was lost, the client will try to restore the
-connection when you execute next command. By default reconnection is performed
-immediately, on next command execution. If the C<reconnect_interval> parameter
-is specified, the client will try to reconnect only after this interval and
-commands executed between reconnections will be queued.
-
-The client will try to reconnect only once and, if attempt fails, the error
-object is passed to command callback. If you need several attempts of the
-reconnection, you must retry a command from the callback as many times, as you
-need.
+If the parameter is specified, the client will try to reconnect only after
+this interval. Commands executed between reconnections will be queued.
 
   reconnect_interval => 5,
 
@@ -1170,33 +1019,9 @@ Specifies L<AnyEvent::Handle> parameters.
     linger   => 60,
   }
 
-Enabling of the C<autocork> parameter can improve performance. See
+Enabling of the C<autocork> parameter can improve perfomance. See
 documentation on L<AnyEvent::Handle> for more information.
 
-=item default_headers => \%headers
-
-Specifies default headers for all outgoing frames.
-
-  default_headers => {
-    'x-foo' => 'foo_value',
-    'x-bar' => 'bar_value',
-  }
-
-=item command_headers
-
-Specifies default headers for particular commands.
-
-  command_headers => {
-    SEND => {
-      receipt => 'auto',
-    },
-
-    SUBSCRIBE => {
-      durable => 'true',
-      ack     => 'client',
-    },
-  }
-
 =item on_connect => $cb->()
 
 The C<on_connect> callback is called when the connection is successfully
@@ -1223,39 +1048,34 @@ an error messages to C<STDERR>.
 
 =head1 COMMAND METHODS
 
-To execute the STOMP command you must call appropriate method. STOMP headers
-can be specified as command parameters. The client automatically adds
-C<content-length> header to all outgoing frames. Every command method can also
-accept two additional parameters: the C<body> parameter where you can specify
-the body of the frame, and the C<on_receipt> parameter that is the alternative
-way to specify the command callback.
+To execute the STOMP command you must call appropriate method. The client
+automaticaly adds C<content-length> header to all outgoing frames. The body of
+the frame you can specify in C<body> parameter of the command method.
 
 If you want to receive C<RECEIPT> frame, you must specify C<receipt> header.
-The C<receipt> header can take the special value C<auto>. If it set, the
-receipt identifier will be generated automatically by the client. The
+The C<receipt> header can take special value C<auto>. In this case the
+value for C<receipt> header will be generated automaticaly by the client.
 C<RECEIPT> frame is passed to the command callback in first argument as the
-object of the class L<AnyEvent::Stomper::Frame>. If the C<receipt> header is
-not specified the first argument of the command callback will be C<undef>.
+object of the class L<AnyEvent::Stomper::Frame>. If the C<receipt> header
+is not specified the first argument of the command callback will be C<undef>.
 
 For commands C<SUBSCRIBE>, C<UNSUBSCRIBE>, C<DISCONNECT> the client
-automatically adds C<receipt> header for internal usage.
+automaticaly adds C<receipt> header for internal usage.
 
-The command callback is called in one of two cases depending on the presence of
-the C<receipt> header. First case, when the command was successfully written to
-the socket. Second case, when the C<RECEIPT> frame will be received. In first
-case C<on_receipt> callback can be called synchronously. If any error occurred
-during the command execution, the error object is passed to the callback in
-second argument. Error object is the instance of the class
-L<AnyEvent::Stomper::Error>.
+The command callback is called after successful sending of the command to the
+server or when C<RECEIPT> frame will be received, in case if C<receipt> header
+is specified. If any error occurred during the command execution, the error
+object is passed to the callback in second argument. Error object is the
+instance of the class L<AnyEvent::Stomper::Error>.
 
 The command callback is optional. If it is not specified and any error
 occurred, the C<on_error> callback of the client is called.
 
 The full list of all available headers for every command you can find in STOMP
-protocol specification and in documentation on your STOMP server. For various
-versions of STOMP protocol and various STOMP servers they can be differ.
+protocol specification and in documentation on your queue broker. For various
+versions of STOMP protocol and various queue brokers they can be differ.
 
-=head2 send( [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 send( [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 Sends a message to a destination in the messaging system.
 
@@ -1288,7 +1108,7 @@ Sends a message to a destination in the messaging system.
     receipt     => 'auto',
     body        => 'Hello, world!',
 
-    on_receipt => sub {
+    sub {
       my $receipt = shift;
       my $err     = shift;
 
@@ -1306,60 +1126,46 @@ Sends a message to a destination in the messaging system.
     }
   );
 
-=head2 subscribe( [ %params ] [, $cb->( $msg ) ] )
+=head2 subscribe( [ %headers ] [, ( $cb->( $receipt, $err ) | \%cbs ) ] )
 
 The method is used to register to listen to a given destination. The
-C<subscribe> method require the C<on_message> callback, which is called on
-every received C<MESSAGE> frame from the server. The C<MESSAGE> frame is passed
+C<subscribe> method require the C<on_message> callback, which is called when
+C<MESSAGE> frame from the server was received. The C<MESSAGE> frame is passed
 to the C<on_message> callback in first argument as the object of the class
-L<AnyEvent::Stomper::Frame>. If the C<subscribe> method is called with one
-callback, this callback will be act as C<on_message> callback.
-
-  $stomper->subscribe(
-    id          => 'foo',
-    destination => '/queue/foo',
-
-    sub {
-      my $msg = shift;
-
-      my $headers = $msg->headers;
-      my $body    = $msg->body;
-
-      # message handling...
-    },
-  );
+L<AnyEvent::Stomper::Frame>.
 
   $stomper->subscribe(
     id          => 'foo',
     destination => '/queue/foo',
     ack         => 'client',
 
-    on_receipt => sub {
-      my $receipt = shift;
-      my $err     = shift;
+    { on_receipt => sub {
+        my $receipt = shift;
+        my $err     = shift;
 
-      if ( defined $err ) {
-        my $err_msg   = $err->message;
-        my $err_code  = $err->code;
-        my $err_frame = $err->frame;
+        if ( defined $err ) {
+          my $err_msg   = $err->message;
+          my $err_code  = $err->code;
+          my $err_frame = $err->frame;
 
-        return;
-      }
+          return;
+        }
 
-      # receipt handling...
-    },
+        # receipt handling...
+      },
 
-    on_message => sub {
-      my $msg = shift;
+      on_message => sub {
+        my $msg = shift;
 
-      my $headers = $msg->headers;
-      my $body    = $msg->body;
+        my $headers = $msg->headers;
+        my $body    = $msg->body;
 
-      # message handling...
-    },
+        # message handling...
+      },
+    }
   );
 
-=head2 unsubscribe( [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 unsubscribe( [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 The method is used to remove an existing subscription.
 
@@ -1383,19 +1189,17 @@ The method is used to remove an existing subscription.
     }
   );
 
-=head2 ack( [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 ack( [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 The method is used to acknowledge consumption of a message from a subscription
 using C<client> or C<client-individual> acknowledgment. Any messages received
 from such a subscription will not be considered to have been consumed until the
-message has been acknowledged via an C<ack()> method. Method C<ack()> must be
-called with required parameter C<message> in which must be specified the
-C<MESSAGE> frame.
+message has been acknowledged via an C<ack()> method.
 
-  $stomper->ack( message => $msg );
+  $stomper->ack( id => $ack_id );
 
   $stomper->ack(
-    message => $msg,
+    id      => $ack_id,
     receipt => 'auto',
 
     sub {
@@ -1414,17 +1218,15 @@ C<MESSAGE> frame.
     }
   );
 
-=head2 nack( [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 nack( [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 The C<nack> method is the opposite of C<ack> method. It is used to tell the
-server that the client did not consume the message. Method C<nack()> must be
-called with required parameter C<message> in which must be specified the
-C<MESSAGE> frame.
+server that the client did not consume the message.
 
-  $stomper->nack( message => $msg );
+  $stomper->nack( id => $ack_id );
 
   $stomper->nack(
-    message => $msg,
+    id      => $ack_id,
     receipt => 'auto',
 
     sub {
@@ -1443,19 +1245,19 @@ C<MESSAGE> frame.
     }
   );
 
-=head2 begin( [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 begin( [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 The method C<begin> is used to start a transaction.
 
-=head2 commit( [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 commit( [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 The method C<commit> is used to commit a transaction.
 
-=head2 abort( [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 abort( [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 The method C<abort> is used to roll back a transaction.
 
-=head2 disconnect( [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 disconnect( [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 A client can disconnect from the server at anytime by closing the socket but
 there is no guarantee that the previously sent frames have been received by
@@ -1463,7 +1265,7 @@ the server. To do a graceful shutdown, where the client is assured that all
 previous frames have been received by the server, you must call C<disconnect>
 method and wait for the C<RECEIPT> frame.
 
-=head2 execute( $command, [ %params ] [, $cb->( $receipt, $err ) ] )
+=head2 execute( $command, [ %headers ] [, $cb->( $receipt, $err ) ] )
 
 An alternative method to execute commands. In some cases it can be more
 convenient.
@@ -1570,14 +1372,9 @@ Gets or sets the C<on_error> callback.
 The method for forced disconnection. All uncompleted operations will be
 aborted.
 
-=head1 WORKING WITH CLUSTER
-
-If you have the cluster of STOMP servers, you can use
-L<AnyEvent::Stomper::Cluster> to work with it.
-
 =head1 SEE ALSO
 
-L<AnyEvent::Stomper::Cluster>
+L<AnyEvent::Stomper::Pool>
 
 =head1 AUTHOR
 
@@ -1587,7 +1384,7 @@ Sponsored by SMS Online, E<lt>dev.opensource@sms-online.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016-2017, Eugene Ponizovsky, SMS Online. All rights reserved.
+Copyright (c) 2016, Eugene Ponizovsky, SMS Online. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
