@@ -4,7 +4,7 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.33_01';
+our $VERSION = '0.02';
 
 our %ERROR_CODES = (
   E_CANT_CONN                  => 1,
@@ -59,7 +59,7 @@ to callbacks.
 
 =head1 CONSTRUCTOR
 
-=head2 new( $err_msg, $err_code [, $frame ] )
+=head2 new( $err_msg, $err_code )
 
 Creates error object.
 
@@ -81,15 +81,10 @@ Gets error frame
 
 L<AnyEvent::Stomper>
 
-=head1 AUTHOR
-
-Eugene Ponizovsky, E<lt>ponizovsky@gmail.comE<gt>
-
-Sponsored by SMS Online, E<lt>dev.opensource@sms-online.comE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016-2017, Eugene Ponizovsky, SMS Online. All rights reserved.
+Copyright (c) 2016, Eugene Ponizovsky, E<lt>ponizovsky@gmail.comE<gt>.
+All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
