@@ -4,22 +4,22 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.33_01';
+our $VERSION = '0.02';
 
 use Encode qw( decode );
 
 
 sub new {
-  my $class   = shift;
-  my $command = shift;
-  my $headers = shift;
-  my $body    = shift;
+  my $class    = shift;
+  my $command  = shift;
+  my $headers  = shift;
+  my $body     = shift;
 
   my $self = bless {}, $class;
 
   $self->{command} = $command;
-  $self->{headers} = $headers;
-  $self->{body}    = $body;
+  $self->{headers} = $headers || {};
+  $self->{body}    = $body || '';
 
   return $self;
 }
@@ -37,6 +37,20 @@ sub new {
   }
 }
 
+sub decoded_body {
+  my $self = shift;
+
+  my $headers = $self->{headers};
+
+  if ( defined $headers->{'content-type'}
+    && $headers->{'content-type'} =~ m/;\s*charset=([^\s;]+)/ )
+  {
+    return decode( $1, $self->{body} );
+  }
+
+  return $self->{body};
+}
+
 1;
 __END__
 
@@ -51,24 +65,28 @@ to callbacks.
 
 =head1 CONSTRUCTOR
 
-=head2 new( $command, \%headers [, $body ] )
+=head2 new( $command, \%headers, $body )
 
 Creates error object.
 
 =head1 METHODS
 
-=head2 command()
+=head2 command( [ $command ] )
 
 Gets command name
 
-=head2 headers()
+=head2 headers( [ $headers ] )
 
 Gets frame headers
 
-=head2 body()
+=head2 body( [ $body ] )
 
 Gets frame body
 
+=head2 decoded_body()
+
+Gest decoded frame body
+
 =head1 SEE ALSO
 
 L<AnyEvent::Stomper>
@@ -81,7 +99,7 @@ Sponsored by SMS Online, E<lt>dev.opensource@sms-online.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016-2017, Eugene Ponizovsky, SMS Online. All rights reserved.
+Copyright (c) 2016, Eugene Ponizovsky, SMS Online. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
