@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.09_02';
+our $VERSION = '0.02';
 
 use AnyEvent::Stomper;
 use Scalar::Util qw( weaken );
@@ -34,7 +34,7 @@ sub new {
   $self->{on_node_error}      = $params{on_node_error};
 
   my %node_params;
-  foreach my $name ( qw( login passcode vhost heartbeat connection_timeout
+  foreach my $name ( qw( login passcode vhost heart_beat connection_timeout
       reconnect_interval handle_params lazy ) )
   {
     next unless defined $params{$name};
@@ -196,9 +196,9 @@ AnyEvent::Stomper::Pool - Connection pool for AnyEvent::Stomper
 
   my $pool = AnyEvent::Stomper::Pool->new(
     nodes => [
-      { host => 'stomp-server-1.com', port => 61613 },
-      { host => 'stomp-server-2.com', port => 61613 },
-      { host => 'stomp-server-3.com', port => 61613 },
+      { host => 'mq-broker-1.com', port => 61613 },
+      { host => 'mq-broker-2.com', port => 61613 },
+      { host => 'mq-broker-3.com', port => 61613 },
     ],
     login    => 'guest',
     passcode => 'guest',
@@ -243,7 +243,7 @@ AnyEvent::Stomper::Pool - Connection pool for AnyEvent::Stomper
 =head1 DESCRIPTION
 
 AnyEvent::Stomper::Pool is connection pool for AnyEvent::Stomper. This module
-can be used to work with cluster or set of STOMP servers.
+can be used to work with cluster of queue brokers.
 
 =head1 CONSTRUCTOR
 
@@ -251,27 +251,27 @@ can be used to work with cluster or set of STOMP servers.
 
   my $stomper = AnyEvent::Stomper::Pool->new(
     nodes => [
-      { host => 'stomp-server-1.com', port => 61613 },
-      { host => 'stomp-server-2.com', port => 61613 },
-      { host => 'stomp-server-3.com', port => 61613 },
+      { host => 'mq-broker-1.com', port => 61613 },
+      { host => 'mq-broker-2.com', port => 61613 },
+      { host => 'mq-broker-3.com', port => 61613 },
     ],
     login              => 'guest',
     passcode           => 'guest',
     vhost              => '/',
-    heartbeat          => [ 5000, 5000 ],
+    heart_beat         => [ 5000, 5000 ],
     connection_timeout => 5,
     lazy               => 1,
     reconnect_interval => 5,
 
-    on_node_connect => sub {
+    on_connect => sub {
       # handling...
     },
 
-    on_node_disconnect => sub {
+    on_disconnect => sub {
       # handling...
     },
 
-    on_node_error => sub {
+    on_error => sub {
       my $err = shift;
 
       # error handling...
@@ -297,7 +297,7 @@ The password used to authenticate against a secured STOMP server.
 
 The name of a virtual host that the client wishes to connect to.
 
-=item heartbeat => \@heartbeat
+=item heart_beat => \@heart_beat
 
 Heart-beating can optionally be used to test the healthiness of the underlying
 TCP connection and to make sure that the remote end is alive and kicking. The
@@ -306,13 +306,16 @@ STOMP server. C<0> means, that the client will not send heart-beats. The second
 number sets interval in milliseconds between incoming heart-beats from the
 STOMP server. C<0> means, that the client does not want to receive heart-beats.
 
-  heartbeat => [ 5000, 5000 ],
+  heart_beat => [ 5000, 5000 ],
 
 Not set by default.
 
 =item connection_timeout => $connection_timeout
 
 Specifies connection timeout. If the client could not connect to the node
+If enabled, the connection establishes at time when you will send the first
+command to the server. By default the connection establishes after calling of
+the C<new> method.
 after specified timeout, the C<on_node_error> callback is called with the
 C<E_CANT_CONN> error. The timeout specifies in seconds and can contain a
 fractional part.
